.. _api:

API
===

AMQP
----

.. automodule:: nameko.amqp.consume
    :members:

.. automodule:: nameko.amqp.publish
    :members:

RPC
^^^

.. automodule:: nameko.rpc
    :members:

Events
^^^^^^

.. automodule:: nameko.events
    :members:

Messaging
^^^^^^^^^

.. automodule:: nameko.messaging
    :members:


Standalone
^^^^^^^^^^

.. automodule:: nameko.standalone
    :members:

.. automodule:: nameko.standalone.rpc
    :members:

.. automodule:: nameko.standalone.events
    :members:

HTTP
----

.. automodule:: nameko.web
    :members:

.. automodule:: nameko.web.handlers
    :members:

.. automodule:: nameko.web.server
    :members:

.. automodule:: nameko.web.websocket
    :members:


Testing
-------

.. automodule:: nameko.testing
    :members:

.. automodule:: nameko.testing.services
    :members:

.. automodule:: nameko.testing.waiting
    :members:

.. automodule:: nameko.testing.utils
    :members:


Utils
-----

.. automodule:: nameko.utils
    :members:

.. automodule:: nameko.utils.retry
    :members:


Core
----


.. automodule:: nameko.containers
    :members:

.. automodule:: nameko.extensions
    :members:

.. automodule:: nameko.exceptions
    :members:

.. automodule:: nameko.serialization
    :members:

.. automodule:: nameko.runners
    :members:
